@@ -27,17 +27,15 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QDebug>
-#include <QDesktopWidget>
 #include <QFileDialog>
 #include <QImageWriter>
 #include <QMenuBar>
 #include <QPainter>
 #include <QPrintDialog>
+#include <QScreen>
 #include <QTemporaryFile>
 
 // include files for KF5
-#include <kxmlgui_version.h>
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KEditToolBar>
@@ -629,7 +627,7 @@ void KmagApp::slotToggleRefresh()
 void KmagApp::slotModeWholeScreen()
 {
   m_zoomView->followMouse(false);
-  m_zoomView->setSelRectPos(QRect (0, 0, QApplication::desktop()->width(), QApplication::desktop()->height()));
+  m_zoomView->setSelRectPos(screen()->virtualGeometry());
   m_zoomView->showSelRect(false);
   m_zoomView->setFitToWindow (false);
   m_modeFollowMouse->setChecked(false);
@@ -824,11 +822,7 @@ void KmagApp::slotShowMenu()
 
 void KmagApp::slotConfKeys()
 {
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5,84,0)
   KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
-#else
-  KShortcutsDialog::configure( actionCollection() );
-#endif
 }
 
 void KmagApp::slotEditToolbars()
